# Generated by Django 4.1.8 on 2023-05-08 06:09

from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="Currency",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("description", models.TextField(blank=True, null=True, verbose_name="description")),
                ("title", models.CharField(max_length=50)),
                ("dlm", models.DateTimeField(blank=True, null=True)),
                ("is_active", models.BooleanField(default=True)),
                ("is_main", models.BooleanField(default=False)),
            ],
            options={
                "verbose_name_plural": "currencies",
                "db_table": "currency",
                "ordering": ("-id",),
            },
        ),
        migrations.CreateModel(
            name="CustomerCart",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                (
                    "user",
                    models.OneToOneField(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="%(class)s",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "db_table": "customer-cart",
                "ordering": ("-id",),
            },
        ),
        migrations.CreateModel(
            name="Order",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                (
                    "status",
                    models.CharField(
                        blank=True,
                        choices=[
                            ("CREATED", "Created"),
                            ("PROCESSING", "Processing"),
                            ("COMPLETED", "Completed"),
                            ("CANCELED", "Refunded"),
                        ],
                        default="CREATED",
                        max_length=255,
                        null=True,
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="%(class)s",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "db_table": "orders",
                "ordering": ("-id",),
            },
        ),
        migrations.CreateModel(
            name="Product",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("description", models.TextField(blank=True, null=True, verbose_name="description")),
                ("title", models.CharField(max_length=50)),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                (
                    "price",
                    models.DecimalField(
                        decimal_places=2, max_digits=6, validators=[django.core.validators.MinValueValidator(0)]
                    ),
                ),
                ("is_active", models.BooleanField(default=True)),
            ],
            options={
                "db_table": "products",
                "ordering": ("-id",),
            },
        ),
        migrations.CreateModel(
            name="Property",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("description", models.TextField(blank=True, null=True, verbose_name="description")),
                ("title", models.CharField(max_length=50)),
                (
                    "unit",
                    models.CharField(
                        blank=True,
                        choices=[
                            ("GRAM", "g"),
                            ("KILOGRAM", "kg"),
                            ("METER", "m"),
                            ("CENTIMETER", "cm"),
                            ("INCH", "in"),
                            ("MILLIMETER", "mm"),
                            ("PIXEL", "px"),
                            ("HERTZ", "Hz"),
                            ("COLOR", "Color"),
                        ],
                        max_length=255,
                        null=True,
                    ),
                ),
            ],
            options={
                "db_table": "properties",
                "ordering": ("-id",),
            },
        ),
        migrations.CreateModel(
            name="ShippingMethod",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("description", models.TextField(blank=True, null=True, verbose_name="description")),
                ("title", models.CharField(max_length=50)),
                ("logo", models.ImageField(blank=True, null=True, upload_to="shipping-methods")),
            ],
            options={
                "db_table": "shipping-methods",
                "ordering": ("-id",),
            },
        ),
        migrations.CreateModel(
            name="Tax",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("description", models.TextField(blank=True, null=True, verbose_name="description")),
                ("title", models.CharField(max_length=50)),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("value", models.DecimalField(decimal_places=2, max_digits=6)),
            ],
            options={
                "verbose_name_plural": "taxes",
                "db_table": "taxes",
                "ordering": ("-id",),
            },
        ),
        migrations.CreateModel(
            name="ProductProperty",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("value", models.CharField(max_length=200)),
                (
                    "product",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="properties",
                        to="drf_shop_api.product",
                    ),
                ),
                (
                    "property",
                    models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to="drf_shop_api.property"),
                ),
            ],
            options={
                "db_table": "product-properties",
                "ordering": ("-id",),
            },
        ),
        migrations.CreateModel(
            name="ProductImage",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("image", models.ImageField(upload_to="")),
                ("is_main", models.BooleanField(default=False)),
                (
                    "product",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, related_name="images", to="drf_shop_api.product"
                    ),
                ),
            ],
            options={
                "db_table": "product-images",
            },
        ),
        migrations.CreateModel(
            name="ProductComment",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("content", models.TextField()),
                (
                    "product",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, related_name="comments", to="drf_shop_api.product"
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="%(class)s",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "db_table": "product-comments",
                "ordering": ("-id",),
            },
        ),
        migrations.CreateModel(
            name="ProductCategory",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("description", models.TextField(blank=True, null=True, verbose_name="description")),
                ("title", models.CharField(max_length=50)),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("url", models.SlugField(max_length=255, unique=True)),
                ("is_active", models.BooleanField(default=True)),
                (
                    "parent",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="children",
                        to="drf_shop_api.productcategory",
                    ),
                ),
            ],
            options={
                "db_table": "product-categories",
            },
        ),
        migrations.AddField(
            model_name="product",
            name="category",
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to="drf_shop_api.productcategory"),
        ),
        migrations.AddField(
            model_name="product",
            name="currency",
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to="drf_shop_api.currency"),
        ),
        migrations.CreateModel(
            name="OrderShipping",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("address", models.CharField(max_length=255)),
                (
                    "status",
                    models.CharField(
                        blank=True,
                        choices=[("CREATED", "Created"), ("FULFILLED", "Fulfilled")],
                        default="CREATED",
                        max_length=255,
                        null=True,
                    ),
                ),
                (
                    "method",
                    models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to="drf_shop_api.shippingmethod"),
                ),
                (
                    "order",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE, related_name="shipping", to="drf_shop_api.order"
                    ),
                ),
            ],
            options={
                "db_table": "order-shippings",
                "ordering": ("-id",),
            },
        ),
        migrations.CreateModel(
            name="OrderProduct",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("quantity", models.IntegerField(default=1)),
                (
                    "order",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, related_name="products", to="drf_shop_api.order"
                    ),
                ),
                (
                    "product",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="order_products",
                        to="drf_shop_api.product",
                    ),
                ),
            ],
            options={
                "db_table": "order-products",
                "ordering": ("-id",),
            },
        ),
        migrations.CreateModel(
            name="CustomerWishList",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("description", models.TextField(blank=True, null=True, verbose_name="description")),
                ("title", models.CharField(max_length=50)),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("products", models.ManyToManyField(blank=True, to="drf_shop_api.product")),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="%(class)s",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "db_table": "customer-wish-list",
                "ordering": ("-id",),
            },
        ),
        migrations.CreateModel(
            name="CustomerCartProduct",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("quantity", models.IntegerField(default=1)),
                (
                    "cart",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="products",
                        to="drf_shop_api.customercart",
                    ),
                ),
                ("product", models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to="drf_shop_api.product")),
            ],
            options={
                "db_table": "customer-cart-product",
                "ordering": ("-id",),
            },
        ),
        migrations.CreateModel(
            name="CustomerBonusWallet",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                (
                    "amount",
                    models.DecimalField(
                        decimal_places=2,
                        default=0,
                        max_digits=6,
                        validators=[django.core.validators.MinValueValidator(0)],
                    ),
                ),
                (
                    "user",
                    models.OneToOneField(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="%(class)s",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "db_table": "customer-bonus-wallet",
                "ordering": ("-id",),
            },
        ),
        migrations.CreateModel(
            name="CurrencyRate",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("rate", models.FloatField()),
                ("is_active", models.BooleanField(default=True)),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                (
                    "from_currency",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="from_rates",
                        to="drf_shop_api.currency",
                    ),
                ),
                (
                    "to_currency",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, related_name="to_rates", to="drf_shop_api.currency"
                    ),
                ),
            ],
            options={
                "db_table": "currency_rates",
                "ordering": ("-id",),
            },
        ),
        migrations.AddIndex(
            model_name="productcategory",
            index=models.Index(fields=["url"], name="product-cat_url_1f4cb0_idx"),
        ),
        migrations.AlterUniqueTogether(
            name="customercartproduct",
            unique_together={("cart", "product")},
        ),
        migrations.AlterUniqueTogether(
            name="currencyrate",
            unique_together={("from_currency", "to_currency")},
        ),
    ]
